@@ -3,7 +3,6 @@ import datetime
 import json
 import os
 import pathlib
-import tempfile
 from functools import partial
 from multiprocessing.pool import Pool
 
@@ -15,11 +14,11 @@ from rebotics_sdk.advanced import remote_loaders
 from rebotics_sdk.cli.common import shell, configure, roles
 from .renderers import format_full_table
 from .utils import ReboticsCLIContext, app_dir, pass_rebotics_context, read_saved_role, process_role
+from ..advanced.flows import FileUploadError, download_vrcdb_file, ReboticsClassificationDatabase
 from ..advanced.packers import ClassificationDatabasePacker, ClassificationDatabaseException, \
     DuplicateFeatureVectorsException, VirtualClassificationDatabasePacker
 from ..constants import RCDB
 from ..providers import AdminProvider, RetailerProvider, sleep
-from ..advanced.flows import FileUploadError, RCDBImportFlow, download_vrcdb_file, ReboticsClassificationDatabase
 from ..providers.facenet import FacenetProvider
 from ..utils import Timer
 
@@ -69,6 +68,9 @@ def get_retailer_version_task(retailer_dict):
 @click.argument('retailer')
 @pass_rebotics_context
 def configurations(ctx, retailer):
+    """
+        Fetch retailer configurations variables
+    """
     try:
         res = ctx.provider.get_configurations(retailer)
         ctx.format_result(res)
@@ -82,6 +84,9 @@ def configurations(ctx, retailer):
 @pass_rebotics_context
 def retailer_versions(ctx, notify, delay):
     """Fetch retailer versions and their meta information"""
+    click.echo("For better experience use: \n"
+               "https://versions.fyn.rocks/ and https://tracker.fyn.rocks/")
+
     if notify:
         if ctx.verbose:
             click.echo('Using notify option', err=True)
@@ -144,22 +149,30 @@ def retailer_versions(ctx, notify, delay):
     click.echo(table)
 
 
-def load_models(ctx, retailer_id, retailer_secret):
-    provider = ctx.provider
-    provider.set_retailer_identifier(retailer_id, retailer_secret)
-    return provider.get_retailer_tf_models()
+@api.command()
+@click.argument('retailer')
+@pass_rebotics_context
+def models(ctx, retailer):
+    """
+        Fetch and display retailer NN configurations
+    """
+    try:
+        ctx.format_result(
+            ctx.provider.get_retailer_tf_models(codename=retailer)
+        )
+    except Exception as exc:
+        raise click.ClickException(exc)
 
 
 @api.command()
-@click.option('-r', '--retailer-id', help='Retailer id')
-@click.option('-s', '--retailer-secret', help='Retailer secret key')
+@click.option('-r', '--retailer', help='Retailer codename')
 @click.option('-u', '--facenet-url', help='Facenet service URL')
 @click.argument('image_url')
 @pass_rebotics_context
-def extract_feature_vectors(ctx, retailer_id, retailer_secret, facenet_url, image_url):
+def extract_feature_vectors(ctx, retailer, facenet_url, image_url):
     """Fetches latest configuration of neural model for retailer by it's ID and Secret key;
     Sends image to facenet to load model into state."""
-    models = load_models(ctx, retailer_id, retailer_secret)
+    models = ctx.provider.get_retailer_tf_models(codename=retailer)
 
     facenet_model = models['facenet_model']
     if ctx.verbose:
@@ -182,16 +195,15 @@ def extract_feature_vectors(ctx, retailer_id, retailer_secret, facenet_url, imag
 
 
 @api.command()
-@click.option('-r', '--retailer-id', help='Retailer id')
-@click.option('-s', '--retailer-secret', help='Retailer secret key')
+@click.option('-r', '--retailer', help='Retailer')
 @click.option('-u', '--facenet-url', help='Facenet service URL')
 @click.argument('image_url')
 @click.argument('bounding_boxes', type=click.File())
 @pass_rebotics_context
-def extract_feature_vectors_for_boxes(ctx, retailer_id, retailer_secret, facenet_url, image_url, bounding_boxes):
+def extract_feature_vectors_for_boxes(ctx, retailer, facenet_url, image_url, bounding_boxes):
     """Fetches latest configuration of neural model for retailer by it's ID and Secret key;
     Sends keyframe image url and list of bounding boxes to facenet to load model into state."""
-    models = load_models(ctx, retailer_id, retailer_secret)
+    models = ctx.get_retailer_tf_models(codename=retailer)
 
     facenet_model = models['facenet_model']
     if ctx.verbose:
@@ -254,7 +266,8 @@ admin pack-classification-db --features features.txt --labels labels.txt --image
 
 admin import_classification_db --retailer delta --model test_code classification.rcdb
     """
-    with RCDBImportFlow(ctx.provider, retailer, model, ClassificationDatabasePacker.extension) as flow:
+    ext = ClassificationDatabasePacker.extension
+    with ctx.provider.rcdb.import_flow(retailer, model, ext) as flow:
         if ctx.verbose:
             click.echo("Creating import request: \n"
                        "retailer: {}\n"
@@ -307,7 +320,7 @@ def import_classification_db(ctx, retailer, model, filepath):
                    "model: {}\n"
                    "extension: {}".format(retailer, model, extension))
 
-    with RCDBImportFlow(ctx.provider, retailer, model, extension) as flow:
+    with ctx.provider.rcdb.import_flow(retailer, model, extension) as flow:
         if ctx.verbose:
             click.echo("Import request: {}".format(flow.import_request))
         with open(filepath, 'rb') as packed:
