@@ -82,9 +82,9 @@ def format_processing_action_output(processing_actions_list, format_):
         pac = processing_actions_list[0]
 
         if 'last_requeue' not in pac.keys():
-            fields = ['id', 'store', 'username', 'status', 'store_planogram_id', 'aisle', 'section', 'created']
+            fields = ['id', 'store_id', 'username', 'status', 'store_planogram_id', 'aisle', 'section', 'created']
         else:
-            fields = ['id', 'store', 'username', 'status', 'store_planogram_id', 'aisle', 'section', 'created',
+            fields = ['id', 'store_id', 'username', 'status', 'store_planogram_id', 'aisle', 'section', 'created',
                       'last_requeue', 'time_in_queue']
 
         format_full_table([PacSerializer(x) for x in processing_actions_list], fields=fields)
