@@ -163,3 +163,22 @@ def download_file_from_dict(d):
     result = download_file(d['url'], d['filepath'])
     click.echo('<< Downloaded file into %s' % d['filepath'], err=True)
     return result
+
+
+class UnrecognizedInputTypeByExtension(Exception):
+    pass
+
+
+def guess_input_type(ext):
+    if ext.startswith('.'):
+        ext = ext.strip('.')
+    if ext in [
+        'jpeg', 'jpg', 'png',
+    ]:
+        return 'image'
+    elif ext in [
+        'mp4', 'mov', 'avi'
+    ]:
+        return 'video'
+    else:
+        raise UnrecognizedInputTypeByExtension('File with extension %s is given' % ext)
